<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
  <context>
    <name>AboutDialogBase</name>
    <message>
      <location filename="src/AboutDialogBase.ui" line="38"/>
      <source>About Synergy</source>
      <translation>O Synergy</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="140"/>
      <location filename="src/AboutDialogBase.ui" line="174"/>
      <source>Unknown</source>
      <translation>Neznámá</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="124"/>
      <source>Version:</source>
      <translation>Verze:</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="53"/>
      <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
      <translation type="unfinished">&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="167"/>
      <source>Build Date: </source>
      <translation type="unfinished">Build Date: </translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="194"/>
      <source>&amp;Ok</source>
      <translation>Ok</translation>
    </message>
  </context>
  <context>
    <name>ActionDialogBase</name>
    <message>
      <location filename="src/ActionDialogBase.ui" line="14"/>
      <source>Configure Action</source>
      <translation>Nastavit akci</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="20"/>
      <source>Choose the action to perform</source>
      <translation>Vyberte akci k provedení</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="26"/>
      <source>Press a hotkey</source>
      <translation>Stisknout klávesovou zkratku</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="36"/>
      <source>Release a hotkey</source>
      <translation>Pustit (uvolnit) klávesy zkratky</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="43"/>
      <source>Press and release a hotkey</source>
      <translation>Stisknout a pustit (uvolnit) klávesy zkratky</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="69"/>
      <source>only on these screens</source>
      <translation>pouze na těchto obrazovkách</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="119"/>
      <source>Switch to screen</source>
      <translation>Přepnout na obrazovku</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="150"/>
      <source>Switch in direction</source>
      <translation>Přepnout směrem</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="174"/>
      <source>left</source>
      <translation>vlevo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="179"/>
      <source>right</source>
      <translation>vpravo</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="184"/>
      <source>up</source>
      <translation>nahoru</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="189"/>
      <source>down</source>
      <translation>dolů</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="201"/>
      <source>Lock cursor to screen</source>
      <translation>Uzamknout kurzor k obrazovce</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="225"/>
      <source>toggle</source>
      <translation>přepnout</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="230"/>
      <source>on</source>
      <translation>zap</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="235"/>
      <source>off</source>
      <translation>vyp</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="247"/>
      <source>Restart server</source>
      <translation type="unfinished">Restart server</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="259"/>
      <source>This action is performed when</source>
      <translation>Tato akce se spustí když</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="265"/>
      <source>the hotkey is pressed</source>
      <translation>je stisknuta klávesová zkratka</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="275"/>
      <source>the hotkey is released</source>
      <translation>jsou puštěny (uvolněny) klávesy zkratky</translation>
    </message>
  </context>
  <context>
    <name>ActivationDialog</name>
    <message>
      <location filename="src/ActivationDialog.ui" line="14"/>
      <source>Activate Synergy</source>
      <translation type="unfinished">Activate Synergy</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="26"/>
      <source>Serial key</source>
      <translation type="unfinished">Serial key</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="33"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This can be found on your &lt;a href=&quot;https://symless.com/synergy/account-login&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;account&lt;/span&gt;&lt;/a&gt; page.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This can be found on your &lt;a href=&quot;https://symless.com/synergy/account-login&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;account&lt;/span&gt;&lt;/a&gt; page.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="49"/>
      <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="88"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="36"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="77"/>
      <source>An error occurred while trying to activate Synergy. Please contact the helpdesk, and provide the following information:

%1</source>
      <translation type="unfinished">An error occurred while trying to activate Synergy. Please contact the helpdesk, and provide the following information:

%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="86"/>
      <source>%1</source>
      <translation type="unfinished">%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="95"/>
      <source>Thanks for trying %1! %5

%2 day%3 of your trial remain%4</source>
      <translation type="unfinished">Thanks for trying %1! %5

%2 day%3 of your trial remain%4</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="114"/>
      <source>Thanks for activating %1!</source>
      <translation type="unfinished">Thanks for activating %1!</translation>
    </message>
  </context>
  <context>
    <name>AddClientDialog</name>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="20"/>
      <source>Dialog</source>
      <translation type="unfinished">Dialog</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="35"/>
      <source>TextLabel</source>
      <translation type="unfinished">TextLabel</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="83"/>
      <source>Ignore auto connect clients</source>
      <translation type="unfinished">Ignore auto connect clients</translation>
    </message>
  </context>
  <context>
    <name>CancelActivationDialog</name>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="14"/>
      <source>Cancel Activation</source>
      <translation type="unfinished">Cancel Activation</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="20"/>
      <source>Are you sure?

If you don&apos;t activate Synergy you&apos;ll be missing out on some great features.</source>
      <translation type="unfinished">Are you sure?

If you don&apos;t activate Synergy you&apos;ll be missing out on some great features.</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="35"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
  </context>
  <context>
    <name>FailedLoginDialog</name>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="14"/>
      <source>Activation Error</source>
      <translation type="unfinished">Activation Error</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="42"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Forgotten your password?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Forgotten your password?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="58"/>
      <source>An error occurred while trying to activate Synergy. The Symless server returned the following error:

%1</source>
      <translation type="unfinished">An error occurred while trying to activate Synergy. The Symless server returned the following error:

%1</translation>
    </message>
  </context>
  <context>
    <name>HotkeyDialogBase</name>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="14"/>
      <source>Hotkey</source>
      <translation>Klávesová zkratka</translation>
    </message>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="20"/>
      <source>Enter the specification for the hotkey:</source>
      <translation>Vytvořte klávesovou zkratku:</translation>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <location filename="src/MainWindow.cpp" line="1000"/>
      <source>&amp;Start</source>
      <translation>&amp;Spustit</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="284"/>
      <source>&amp;File</source>
      <translation>Soubor</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="285"/>
      <source>&amp;Edit</source>
      <translation>Upra&amp;vit</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="286"/>
      <source>&amp;Window</source>
      <translation>O&amp;kno</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="287"/>
      <source>&amp;Help</source>
      <translation>&amp;Nápověda</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="432"/>
      <source>&lt;p&gt;Your version of Synergy is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
      <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
      <translation>&lt;p&gt;Používáte starou verzi aplikace Synergy. Ke &lt;a href=&quot;%2&quot;&gt;stažení&lt;/a&gt; je nyní již verze &lt;b&gt;%1&lt;/b&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="494"/>
      <source>Synergy is now connected. You can close the config window and Synergy will remain connected in the background.</source>
      <translation type="unfinished">Synergy is now connected. You can close the config window and Synergy will remain connected in the background.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="546"/>
      <source>You are connecting to a server. Here is it&apos;s fingerprint:

%1

Compare this fingerprint to the one on your server&apos;s screen.If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
      <translation type="unfinished">You are connecting to a server. Here is it&apos;s fingerprint:

%1

Compare this fingerprint to the one on your server&apos;s screen.If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>Program can not be started</source>
      <translation>Program nelze spustit</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
      <translation>Program &lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt; existuje, ale nelze jej spustit. Ověřte, zda máte potřebná (souborová) oprávnění ke spuštění tohoto programu.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="761"/>
      <source>Synergy client not found</source>
      <translation>Synergy klient nebyl nalezen</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="762"/>
      <source>The executable for the synergy client does not exist.</source>
      <translation>Spustitelný soubor s programem Synergy klienta neexistuje.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="789"/>
      <source>No server selected</source>
      <translation type="unfinished">No server selected</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="790"/>
      <source>No auto config server was selected, try manual mode instead.</source>
      <translation type="unfinished">No auto config server was selected, try manual mode instead.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="805"/>
      <source>Hostname is empty</source>
      <translation>Nevyplněn cílový počítač</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="806"/>
      <source>Please fill in a hostname for the synergy client to connect to.</source>
      <translation>Vyplňte adresu cílového počítače ke kterému se Synergy klient má připojit.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>Cannot write configuration file</source>
      <translation>Do souboru s nastaveními nelze zapisovat</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>The temporary configuration file required to start synergy can not be written.</source>
      <translation>Do dočasného souboru s nastaveními, potřebného pro spuštění Synergy, nelze zapisovat.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="844"/>
      <source>Configuration filename invalid</source>
      <translation>Neplatný název souboru s nastaveními.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="845"/>
      <source>You have not filled in a valid configuration file for the synergy server. Do you want to browse for the configuration file now?</source>
      <translation>Nevyplnili jste platný soubor s nastaveními pro synergy server. Chcete nyní určit umístění souboru s nastaveními?</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="873"/>
      <source>Synergy server not found</source>
      <translation>Synergy server nebyl nalezen</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="874"/>
      <source>The executable for the synergy server does not exist.</source>
      <translation>Spustitelný soubor s programem synergy serveru neexistuje.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="993"/>
      <source>&amp;Stop</source>
      <translation>Za&amp;stavit</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1016"/>
      <source>Synergy is waiting for clients</source>
      <translation type="unfinished">Synergy is waiting for clients</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1023"/>
      <source>Synergy is connected (with %1)</source>
      <translation type="unfinished">Synergy is connected (with %1)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1026"/>
      <source>Synergy is running (without TLS encryption)</source>
      <translation type="unfinished">Synergy is running (without TLS encryption)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1031"/>
      <source>Synergy is starting...</source>
      <translation type="unfinished">Synergy is starting...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1034"/>
      <source>There was an error, retrying...</source>
      <translation type="unfinished">There was an error, retrying...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1037"/>
      <source>Synergy is not running</source>
      <translation type="unfinished">Synergy is not running</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1354"/>
      <source>Please add the server (%1) to the grid.</source>
      <translation type="unfinished">Please add the server (%1) to the grid.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1360"/>
      <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
      <translation type="unfinished">Please drag the new client screen (%1) to the desired position on the grid.</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1093"/>
      <source>Unknown</source>
      <translation>Neznámá</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1247"/>
      <source>Browse for a synergys config file</source>
      <translation>Otevřít existující soubor s nastaveními pro synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="545"/>
      <source>Security question</source>
      <translation type="unfinished">Security question</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1260"/>
      <source>Save configuration as...</source>
      <translation>Uložit nastavení jako…</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Save failed</source>
      <translation>Uložení se nezdařilo</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Could not save configuration to file.</source>
      <translation>Nelze uložit nastavení do souboru.</translation>
    </message>
  </context>
  <context>
    <name>MainWindowBase</name>
    <message>
      <location filename="src/MainWindowBase.ui" line="26"/>
      <source>Synergy</source>
      <translation type="unfinished">Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="216"/>
      <source>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</source>
      <translation>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="525"/>
      <location filename="src/MainWindowBase.ui" line="562"/>
      <source>&amp;Start</source>
      <translation>&amp;Spustit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="307"/>
      <source>Use existing configuration:</source>
      <translation>Použít existující nastavení:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="58"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; days of your Synergy Pro trial remain. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; days of your Synergy Pro trial remain. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="257"/>
      <source>SSL Fingerprint:</source>
      <translation type="unfinished">SSL Fingerprint:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="316"/>
      <source>&amp;Configuration file:</source>
      <translation>Sou&amp;bor s nastaveními:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="336"/>
      <source>&amp;Browse...</source>
      <translation>Pr&amp;ocházet…</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="273"/>
      <source>Configure interactively:</source>
      <translation>Interaktivní nastavení:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="285"/>
      <source>&amp;Configure Server...</source>
      <translation>N&amp;astavit Server…</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="369"/>
      <source>Client name:</source>
      <translation type="unfinished">Client name:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="383"/>
      <source>&amp;Server:</source>
      <translation type="unfinished">&amp;Server:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="405"/>
      <source>Hostname or IP address of the server computer.</source>
      <translation type="unfinished">Hostname or IP address of the server computer.</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="428"/>
      <source>Server:</source>
      <translation type="unfinished">Server:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="495"/>
      <source>Ready</source>
      <translation>Připraven</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="438"/>
      <source>Log</source>
      <translation>Protokol</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="518"/>
      <source>&amp;Apply</source>
      <translation>&amp;Použít</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="233"/>
      <source>IP addresses:</source>
      <translation>IP adresy:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="354"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard):</source>
      <translation>&amp;Client (use another computer&apos;s mouse and keyboard):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="535"/>
      <source>&amp;About Synergy...</source>
      <translation>&amp;O Synergy…</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="543"/>
      <source>Visit &amp;help site</source>
      <translation type="unfinished">Visit &amp;help site</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="551"/>
      <source>&amp;Quit</source>
      <translation>&amp;Ukončit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="554"/>
      <source>Quit</source>
      <translation>Ukončit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="565"/>
      <source>Run</source>
      <translation>Spustit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="576"/>
      <source>S&amp;top</source>
      <translation>Zas&amp;tavit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="579"/>
      <source>Stop</source>
      <translation>Zastavit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="587"/>
      <source>S&amp;how Status</source>
      <translation>Zobrazit stav</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="595"/>
      <source>&amp;Hide</source>
      <translation>Skrýt</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="598"/>
      <source>Hide</source>
      <translation>Skrýt</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="606"/>
      <source>&amp;Show</source>
      <translation>&amp;Zobrazit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="609"/>
      <source>Show</source>
      <translation>Zobrazit</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="617"/>
      <source>Save configuration &amp;as...</source>
      <translation>Uložit nastavení j&amp;ako…</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="620"/>
      <source>Save the interactively generated server configuration to a file.</source>
      <translation>Uložit interaktivně vytvořené nastavení serveru do souboru.</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="628"/>
      <source>Settings</source>
      <translation>Nastavení</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="631"/>
      <source>Edit settings</source>
      <translation>Upravit nastavení</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="639"/>
      <location filename="src/MainWindowBase.ui" line="642"/>
      <source>Activate</source>
      <translation type="unfinished">Activate</translation>
    </message>
  </context>
  <context>
    <name>NewScreenWidget</name>
    <message>
      <location filename="src/NewScreenWidget.cpp" line="32"/>
      <source>Unnamed</source>
      <translation>Nepojmenováno</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="src/MainWindow.cpp" line="62"/>
      <source>Synergy Configurations (*.sgc);;All files (*.*)</source>
      <translation>Nastavení Synergy (*.sgc);;Všechny soubory (*.*)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="65"/>
      <source>Synergy Configurations (*.conf);;All files (*.*)</source>
      <translation>Nastavení Synergy (*.conf);;Všechny soubory (*.*)</translation>
    </message>
    <message>
      <location filename="src/main.cpp" line="138"/>
      <source>System tray is unavailable, don&apos;t close your window.</source>
      <translation type="unfinished">System tray is unavailable, don&apos;t close your window.</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialog</name>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
      <source>Screen name is empty</source>
      <translation>Název obrazovky nebyl vyplněn</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
      <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
      <translation>Název obrazovky nemůže zůstat prázdný. Buď jej vyplňte, nebo dialog zrušte.</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
      <source>Screen name matches alias</source>
      <translation>Název obrazovky koliduje s jejím alternativním názvem</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
      <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
      <translation>Název obrazovky a zástupný název být stejné. Buď zástupný název odeberte nebo změňte název obrazovky.</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialogBase</name>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="14"/>
      <source>Screen Settings</source>
      <translation>Natavení obrazovky</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="22"/>
      <source>Screen &amp;name:</source>
      <translation>Název &amp;plochy</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="42"/>
      <source>A&amp;liases</source>
      <translation>A&amp;lternativní názvy</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="57"/>
      <source>&amp;Add</source>
      <translation>Přid&amp;at</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="74"/>
      <source>&amp;Remove</source>
      <translation>Odst&amp;ranit</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="97"/>
      <source>&amp;Modifier keys</source>
      <translation>&amp;Modifikátory (klávesy)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="106"/>
      <source>&amp;Shift:</source>
      <translation type="unfinished">&amp;Shift:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="117"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="164"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="211"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="258"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="305"/>
      <source>Shift</source>
      <translation type="unfinished">Shift</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="122"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="169"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="216"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="263"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="310"/>
      <source>Ctrl</source>
      <translation type="unfinished">Ctrl</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="127"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="174"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="221"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="268"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="315"/>
      <source>Alt</source>
      <translation type="unfinished">Alt</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="132"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="179"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="226"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="273"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="320"/>
      <source>Meta</source>
      <translation type="unfinished">Meta</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="137"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="184"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="231"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="278"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="325"/>
      <source>Super</source>
      <translation type="unfinished">Super</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="142"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="189"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="236"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="283"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="330"/>
      <source>None</source>
      <translation>Žádné</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="150"/>
      <source>&amp;Ctrl:</source>
      <translation type="unfinished">&amp;Ctrl:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="197"/>
      <source>Al&amp;t:</source>
      <translation type="unfinished">Al&amp;t:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="244"/>
      <source>M&amp;eta:</source>
      <translation>Meta:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="291"/>
      <source>S&amp;uper:</source>
      <translation>Super:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="358"/>
      <source>&amp;Dead corners</source>
      <translation>Nevyužité rohy</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="367"/>
      <source>Top-left</source>
      <translation>Vlevo nahoře</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="374"/>
      <source>Top-right</source>
      <translation>Vpravo nahoře</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="381"/>
      <source>Bottom-left</source>
      <translation>Vlevo dole</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="388"/>
      <source>Bottom-right</source>
      <translation>Vpravo dole</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="397"/>
      <source>Corner Si&amp;ze:</source>
      <translation>Velikost ro&amp;hu:</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="428"/>
      <source>&amp;Fixes</source>
      <translation>&amp;Opravy</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="437"/>
      <source>Fix CAPS LOCK key</source>
      <translation>Oprava chování klávesy Caps Lock</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="444"/>
      <source>Fix NUM LOCK key</source>
      <translation>Oprava chování klávesy Num Lock</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="451"/>
      <source>Fix SCROLL LOCK key</source>
      <translation>Oprava chování klávesy Scroll Lock</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="458"/>
      <source>Fix XTest for Xinerama</source>
      <translation>Oprava chování rozšíření grafického serveru X – XTest a Xinerama</translation>
    </message>
  </context>
  <context>
    <name>ScreenSetupModel</name>
    <message>
      <location filename="src/ScreenSetupModel.cpp" line="51"/>
      <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
      <translation>&lt;center&gt;Obrazovka: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Dvojklikem upravíte nastavení&lt;br&gt;Přetažením do koše obrazovku smažete</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialog</name>
    <message>
      <location filename="src/ServerConfigDialog.cpp" line="83"/>
      <source>Configure server</source>
      <translation type="unfinished">Configure server</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialogBase</name>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="14"/>
      <source>Server Configuration</source>
      <translation>Nastavení serveru</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="24"/>
      <source>Screens and links</source>
      <translation>Obrazovky a propojení</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="35"/>
      <source>Drag a screen from the grid to the trashcan to remove it.</source>
      <translation>Obrazovku odstraníte jejím přetažením z mřížky do koše.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="60"/>
      <source>Configure the layout of your synergy server configuration.</source>
      <translation>Nastavte rozložení svého nastavení serveru synergy.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="73"/>
      <source>Drag this button to the grid to add a new screen.</source>
      <translation>Novou obrazovku vytvoříte přetažením tohoto tlačítka do mřížky.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="128"/>
      <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
      <translation>Přetáhněte nové obrazovky do mřížky nebo přesuňte stávající.
Přetáhnutím obrazovky do koše ji smažete.
Nastavení obrazovky upravíte dvojklikem na ni.</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="157"/>
      <source>Hotkeys</source>
      <translation>Klávesové zkratky</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="163"/>
      <source>&amp;Hotkeys</source>
      <translation>&amp;Klávesové zkratky</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="175"/>
      <source>&amp;New</source>
      <translation>&amp;Nová</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="185"/>
      <source>&amp;Edit</source>
      <translation>Upra&amp;vit</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="195"/>
      <source>&amp;Remove</source>
      <translation>Odst&amp;ranit</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="218"/>
      <source>A&amp;ctions</source>
      <translation>Ak&amp;ce</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="230"/>
      <source>Ne&amp;w</source>
      <translation>No&amp;vá</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="240"/>
      <source>E&amp;dit</source>
      <translation>Upravi&amp;t</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="250"/>
      <source>Re&amp;move</source>
      <translation>Ode&amp;brat</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="274"/>
      <source>Advanced server settings</source>
      <translation>Pokročilé nastavení serveru</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="280"/>
      <source>&amp;Switch</source>
      <translation>Přepnout</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="291"/>
      <source>Switch &amp;after waiting</source>
      <translation>Přepnout po prodlevě</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="330"/>
      <location filename="src/ServerConfigDialogBase.ui" line="383"/>
      <location filename="src/ServerConfigDialogBase.ui" line="552"/>
      <source>ms</source>
      <translation type="unfinished">ms</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="344"/>
      <source>Switch on double &amp;tap within</source>
      <translation>Přepnout po dvojitém doteku během</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="408"/>
      <source>&amp;Options</source>
      <translation>M&amp;ožnosti</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="416"/>
      <source>Enable clipboard sharing</source>
      <translation type="unfinished">Enable clipboard sharing</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="452"/>
      <source>MB</source>
      <translation type="unfinished">MB</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="461"/>
      <source>Enable drag and drop file transfers</source>
      <translation type="unfinished">Enable drag and drop file transfers</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="513"/>
      <source>&amp;Check clients every</source>
      <translation>Kontrolovat klienty každých</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="481"/>
      <source>Use &amp;relative mouse moves</source>
      <translation>Používat relativní pohyby myši</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="564"/>
      <source>S&amp;ynchronize screen savers</source>
      <translation>S&amp;ynchronizovat šetřiče obrazovky</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="471"/>
      <source>Don&apos;t take &amp;foreground window on Windows servers</source>
      <translation>Na serverech s Windows se nepřepínat do popředí</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="501"/>
      <source>Ignore auto config clients</source>
      <translation type="unfinished">Ignore auto config clients</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="571"/>
      <source>Disable lock to screen</source>
      <translation type="unfinished">Disable lock to screen</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="581"/>
      <source>&amp;Dead corners</source>
      <translation>Nevyužité rohy</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="590"/>
      <source>To&amp;p-left</source>
      <translation>Levý horní</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="597"/>
      <source>Top-rig&amp;ht</source>
      <translation>Pravý &amp;horní</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="604"/>
      <source>&amp;Bottom-left</source>
      <translation>Spodní levý</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="611"/>
      <source>Bottom-ri&amp;ght</source>
      <translation>Spodní pravý</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="633"/>
      <source>Cor&amp;ner Size:</source>
      <translation>Velikost rohu:</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialog</name>
    <message>
      <location filename="src/SettingsDialog.cpp" line="184"/>
      <source>Save log file to...</source>
      <translation>Uložit soubor s protokolem do…</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialogBase</name>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="14"/>
      <source>Settings</source>
      <translation>Nastavení</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="21"/>
      <source>&amp;Settings Scope</source>
      <translation type="unfinished">&amp;Settings Scope</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="27"/>
      <source>System</source>
      <translation type="unfinished">System</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="37"/>
      <source>User</source>
      <translation type="unfinished">User</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="59"/>
      <source>Sc&amp;reen name:</source>
      <translation>Název ob&amp;razovky:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="76"/>
      <source>P&amp;ort:</source>
      <translation type="unfinished">P&amp;ort:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="105"/>
      <source>&amp;Interface:</source>
      <translation>Rozhraní:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="147"/>
      <source>Specify when the Synergy service should run at an elevated privilege level</source>
      <translation type="unfinished">Specify when the Synergy service should run at an elevated privilege level</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="154"/>
      <source>As Needed</source>
      <translation type="unfinished">As Needed</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="159"/>
      <source>Always</source>
      <translation type="unfinished">Always</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="164"/>
      <source>Never</source>
      <translation type="unfinished">Never</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="172"/>
      <source>Elevate</source>
      <translation type="unfinished">Elevate</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="186"/>
      <source>Minimize to System &amp;Tray</source>
      <translation type="unfinished">Minimize to System &amp;Tray</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="221"/>
      <source>&amp;Network</source>
      <translation type="unfinished">&amp;Network</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="253"/>
      <source>Enable &amp;TLS Encryption</source>
      <translation type="unfinished">Enable &amp;TLS Encryption</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="263"/>
      <source>Enable Auto Config</source>
      <translation type="unfinished">Enable Auto Config</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="270"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Install Bonjour&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Install Bonjour&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="280"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Upgrade to Pro&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Upgrade to Pro&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="179"/>
      <source>&amp;Hide on startup</source>
      <translation type="unfinished">&amp;Hide on startup</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="320"/>
      <source>Logging</source>
      <translation>Protokolování</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="338"/>
      <source>&amp;Logging level:</source>
      <translation>Stupeň podrobnosti protoko&amp;lování:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="372"/>
      <source>Log to file:</source>
      <translation>Protokolovat do souboru:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="389"/>
      <source>Browse...</source>
      <translation>Procházet…</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="134"/>
      <source>&amp;Language:</source>
      <translation>&amp;Jazyk:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="47"/>
      <source>&amp;Miscellaneous</source>
      <translation>Různé</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="349"/>
      <source>Info</source>
      <translation>Informace</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="354"/>
      <source>Debug</source>
      <translation>Ladění</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="359"/>
      <source>Debug1</source>
      <translation>Ladění1</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="364"/>
      <source>Debug2</source>
      <translation>Ladění2</translation>
    </message>
  </context>
  <context>
    <name>SetupWizard</name>
    <message>
      <location filename="src/SetupWizard.cpp" line="65"/>
      <source>Setup Synergy</source>
      <translation>Instalovat Synergy</translation>
    </message>
    <message>
      <location filename="src/SetupWizard.cpp" line="75"/>
      <source>Please select an option.</source>
      <translation>Zvolte možnost.</translation>
    </message>
  </context>
  <context>
    <name>SetupWizardBase</name>
    <message>
      <location filename="src/SetupWizardBase.ui" line="26"/>
      <source>Setup Synergy</source>
      <translation>Instalovat Synergy</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="30"/>
      <source>Welcome</source>
      <translation>Vítejte</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="39"/>
      <source>Thanks for installing Synergy!</source>
      <translation>Těší nás, že jste si nainstalovali Synergy!</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="114"/>
      <source>Synergy lets you easily share your mouse and keyboard between multiple computers on your desk, and it&apos;s Free and Open Source. Just move your mouse off the edge of one computer&apos;s screen on to another. You can even share all of your clipboards. All you need is a network connection. Synergy is cross-platform (works on Windows, Mac OS X and Linux).</source>
      <translation>Synergy vám umožní snadno sdílet myš a klávesnici napříč vícero počítači na vašem stole. Aplikace je svobodná a s otevřeným zdrojovým kódem. Stačí jen přesunout kurzor myši mimo okraj obrazovky jednoho počítače na obrazovku dalšího. Mezi počítači můžete dokonce sdílet obsahy jejich schránek. Jediné, co je potřeba, je propojení sítí. Synergy je multiplatformní (funguje na Windows, Mac OS X a GNU/Linux).</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="159"/>
      <source>My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer&apos;s screen. There can only be one server in your setup.</source>
      <translation type="unfinished">My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer&apos;s screen. There can only be one server in your setup.</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="204"/>
      <source>You have already set up a server. This computer will be controlled using the server&apos;s mouse and keyboard. There can be many clients in your setup.</source>
      <translation type="unfinished">You have already set up a server. This computer will be controlled using the server&apos;s mouse and keyboard. There can be many clients in your setup.</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="146"/>
      <source>&amp;Server (share this computer&apos;s mouse and keyboard)</source>
      <translation>&amp;Server (share this computer&apos;s mouse and keyboard)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="191"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard)</source>
      <translation>&amp;Client (use another computer&apos;s mouse and keyboard)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="131"/>
      <source>Server or Client?</source>
      <translation>Server nebo klient?</translation>
    </message>
  </context>
  <context>
    <name>SslCertificate</name>
    <message>
      <location filename="src/SslCertificate.cpp" line="46"/>
      <source>Failed to get profile directory.</source>
      <translation type="unfinished">Failed to get profile directory.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="148"/>
      <source>SSL certificate generated.</source>
      <translation type="unfinished">SSL certificate generated.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="178"/>
      <source>SSL fingerprint generated.</source>
      <translation type="unfinished">SSL fingerprint generated.</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="181"/>
      <source>Failed to find SSL fingerprint.</source>
      <translation type="unfinished">Failed to find SSL fingerprint.</translation>
    </message>
  </context>
  <context>
    <name>VersionChecker</name>
    <message>
      <location filename="src/VersionChecker.cpp" line="145"/>
      <source>Unknown</source>
      <translation>Neznámá</translation>
    </message>
  </context>
  <context>
    <name>ZeroconfService</name>
    <message>
      <location filename="src/ZeroconfService.cpp" line="82"/>
      <source>zeroconf server detected: %1</source>
      <translation type="unfinished">zeroconf server detected: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="91"/>
      <source>zeroconf client detected: %1</source>
      <translation type="unfinished">zeroconf client detected: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="100"/>
      <location filename="src/ZeroconfService.cpp" line="132"/>
      <location filename="src/ZeroconfService.cpp" line="143"/>
      <source>Synergy Auto Config</source>
      <translation type="unfinished">Synergy Auto Config</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="133"/>
      <source>Unable to start zeroconf: %1.</source>
      <translation type="unfinished">Unable to start zeroconf: %1.</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="101"/>
      <source>Error code: %1.</source>
      <translation type="unfinished">Error code: %1.</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="144"/>
      <source>Failed to get local IP address. Please manually type in server address on your clients</source>
      <translation type="unfinished">Failed to get local IP address. Please manually type in server address on your clients</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="150"/>
      <location filename="src/ZeroconfService.cpp" line="157"/>
      <source>%1</source>
      <translation type="unfinished">%1</translation>
    </message>
  </context>
</TS>
